==> angelscript_2.33.0.zip: sdk/docs/manual/doc_advanced.js <==
var doc_advanced =
[
    [ "Debugging scripts", "doc_debug.html", [
      [ "Setting line breaks", "doc_debug.html#doc_debug_1", null ],
      [ "Viewing the call stack", "doc_debug.html#doc_debug_2", null ],
      [ "Inspecting variables", "doc_debug.html#doc_debug_3", null ],
      [ "Debugging internally executed scripts", "doc_debug.html#doc_debug_4", null ]
    ] ],
    [ "Timeout long running scripts", "doc_adv_timeout.html", [
      [ "With the line callback", "doc_adv_timeout.html#doc_adv_timeout_1", null ],
      [ "With a secondary thread", "doc_adv_timeout.html#doc_adv_timeout_2", null ]
    ] ],
    [ "Garbage collection", "doc_gc.html", [
      [ "Callback for detected circular references", "doc_gc.html#doc_gc_circcallback", null ],
      [ "Garbage collection and multi-threading", "doc_gc.html#doc_gc_threads", null ]
    ] ],
    [ "Multithreading", "doc_adv_multithread.html", [
      [ "Things to think about with a multithreaded environment", "doc_adv_multithread.html#doc_adv_multithread_1", null ],
      [ "Fibers", "doc_adv_multithread.html#doc_adv_fibers", null ]
    ] ],
    [ "Concurrent scripts", "doc_adv_concurrent.html", null ],
    [ "Co-routines", "doc_adv_coroutine.html", null ],
    [ "Dynamic compilations", "doc_adv_dynamic_build.html", [
      [ "On demand builds", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_ondemand", null ],
      [ "Incremental builds", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_incr", null ],
      [ "Hot reloading scripts", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_hot", [
        [ "Things to consider", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_hot_1", null ]
      ] ]
    ] ],
    [ "Pre-compiled byte code", "doc_adv_precompile.html", [
      [ "Things to remember", "doc_adv_precompile.html#doc_adv_precompile_1", null ]
    ] ],
    [ "Fine tuning", "doc_finetuning.html", [
      [ "Cache the functions and types", "doc_finetuning.html#doc_finetuning_1", null ],
      [ "Reuse the context object", "doc_finetuning.html#doc_finetuning_2", [
        [ "Context pool", "doc_finetuning.html#doc_finetuning_2_1", null ],
        [ "Nested calls", "doc_finetuning.html#doc_finetuning_2_2", null ]
      ] ],
      [ "Compile scripts without line cues", "doc_finetuning.html#doc_finetuning_3", null ],
      [ "Disable thread safety", "doc_finetuning.html#doc_finetuning_4", null ],
      [ "Turn off automatic garbage collection", "doc_finetuning.html#doc_finetuning_5", null ],
      [ "Compare native calling convention versus generic calling convention", "doc_finetuning.html#doc_finetuning_6", null ]
    ] ],
    [ "Access masks and exposing different interfaces", "doc_adv_access_mask.html", null ],
    [ "Using namespaces", "doc_adv_namespace.html", [
      [ "Registering the interface with namespaces", "doc_adv_namespace.html#doc_adv_namespace_reg", null ],
      [ "Finding entities in namespaces", "doc_adv_namespace.html#doc_adv_namespace_enum", null ]
    ] ],
    [ "Dynamic configurations", "doc_adv_dynamic_config.html", null ],
    [ "Custom options", "doc_adv_custom_options.html", [
      [ "Registerable types", "doc_adv_custom_options.html#doc_adv_custom_options_reg_types", null ],
      [ "Language modifications", "doc_adv_custom_options.html#doc_adv_custom_options_lang_mod", null ],
      [ "Engine behaviours", "doc_adv_custom_options.html#doc_adv_custom_options_engine", null ]
    ] ],
    [ "Reflection", "doc_adv_reflection.html", [
      [ "Enumerating variables and properties", "doc_adv_reflection.html#doc_adv_reflection_vars", null ],
      [ "Enumerating functions and methods", "doc_adv_reflection.html#doc_adv_reflection_funcs", null ],
      [ "Enumerating types", "doc_adv_reflection.html#doc_adv_reflection_types", null ]
    ] ],
    [ "Inheriting from application registered class", "doc_adv_inheritappclass.html", null ],
    [ "JIT compilation", "doc_adv_jit_topic.html", "doc_adv_jit_topic" ]
];

==> angelscript_2.38.0.zip: sdk/docs/manual/doc_advanced.js <==
var doc_advanced =
[
    [ "Debugging scripts", "doc_debug.html", [
      [ "Setting line breaks", "doc_debug.html#doc_debug_1", null ],
      [ "Viewing the call stack", "doc_debug.html#doc_debug_2", null ],
      [ "Inspecting variables", "doc_debug.html#doc_debug_3", null ],
      [ "Debugging internally executed scripts", "doc_debug.html#doc_debug_4", null ]
    ] ],
    [ "Timeout long running scripts", "doc_adv_timeout.html", [
      [ "With the line callback", "doc_adv_timeout.html#doc_adv_timeout_1", null ],
      [ "With a secondary thread", "doc_adv_timeout.html#doc_adv_timeout_2", null ]
    ] ],
    [ "Garbage collection", "doc_gc.html", [
      [ "Callback for detected circular references", "doc_gc.html#doc_gc_circcallback", null ],
      [ "Garbage collection and multi-threading", "doc_gc.html#doc_gc_threads", null ]
    ] ],
    [ "Multithreading", "doc_adv_multithread.html", [
      [ "Things to think about with a multithreaded environment", "doc_adv_multithread.html#doc_adv_multithread_1", null ],
      [ "Fibers", "doc_adv_multithread.html#doc_adv_fibers", null ]
    ] ],
    [ "Concurrent scripts", "doc_adv_concurrent.html", null ],
    [ "Co-routines", "doc_adv_coroutine.html", null ],
    [ "Import functions", "doc_adv_import.html", null ],
    [ "Dynamic compilations", "doc_adv_dynamic_build.html", [
      [ "On demand builds", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_ondemand", null ],
      [ "Incremental builds", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_incr", null ],
      [ "Hot reloading scripts", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_hot", [
        [ "Things to consider", "doc_adv_dynamic_build.html#doc_adv_dynamic_build_hot_1", null ]
      ] ]
    ] ],
    [ "Pre-compiled byte code", "doc_adv_precompile.html", [
      [ "Things to remember", "doc_adv_precompile.html#doc_adv_precompile_1", null ]
    ] ],
    [ "Fine tuning", "doc_finetuning.html", [
      [ "Cache the functions and types", "doc_finetuning.html#doc_finetuning_1", null ],
      [ "Reuse the context object", "doc_finetuning.html#doc_finetuning_2", [
        [ "Context pool", "doc_finetuning.html#doc_finetuning_2_1", null ],
        [ "Nested calls", "doc_finetuning.html#doc_finetuning_2_2", null ]
      ] ],
      [ "Compile scripts without line cues", "doc_finetuning.html#doc_finetuning_3", null ],
      [ "Disable thread safety", "doc_finetuning.html#doc_finetuning_4", null ],
      [ "Turn off automatic garbage collection", "doc_finetuning.html#doc_finetuning_5", null ],
      [ "Compare native calling convention versus generic calling convention", "doc_finetuning.html#doc_finetuning_6", null ]
    ] ],
    [ "Access masks and exposing different interfaces", "doc_adv_access_mask.html", null ],
    [ "Using namespaces", "doc_adv_namespace.html", [
      [ "Registering the interface with namespaces", "doc_adv_namespace.html#doc_adv_namespace_reg", null ],
      [ "Finding entities in namespaces", "doc_adv_namespace.html#doc_adv_namespace_enum", null ]
    ] ],
    [ "Dynamic configurations", "doc_adv_dynamic_config.html", null ],
    [ "Custom options", "doc_adv_custom_options.html", [
      [ "Registerable types", "doc_adv_custom_options.html#doc_adv_custom_options_reg_types", null ],
      [ "Language modifications", "doc_adv_custom_options.html#doc_adv_custom_options_lang_mod", null ],
      [ "Engine behaviours", "doc_adv_custom_options.html#doc_adv_custom_options_engine", null ]
    ] ],
    [ "Reflection", "doc_adv_reflection.html", [
      [ "Enumerating variables and properties", "doc_adv_reflection.html#doc_adv_reflection_vars", null ],
      [ "Enumerating functions and methods", "doc_adv_reflection.html#doc_adv_reflection_funcs", null ],
      [ "Enumerating types", "doc_adv_reflection.html#doc_adv_reflection_types", null ]
    ] ],
    [ "Serialization", "doc_serialization.html", [
      [ "Serialization of modules", "doc_serialization.html#doc_serialization_modules", null ],
      [ "Serialization of global variables", "doc_serialization.html#doc_serialization_vars", null ],
      [ "Serialization of objects", "doc_serialization.html#doc_serialization_objects", null ],
      [ "Serialization of contexts", "doc_serialization.html#doc_serialization_contexts", null ]
    ] ],
    [ "Inheriting from application registered class", "doc_adv_inheritappclass.html", null ],
    [ "JIT compilation", "doc_adv_jit_topic.html", "doc_adv_jit_topic" ]
];
